# sromaster
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.22
- Package version: 0.1.22
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://nexium.me/](https://nexium.me/)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import sromaster
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sromaster
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import sromaster
from sromaster.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = sromaster.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = sromaster.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
async with sromaster.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = sromaster.CustomersApi(api_client)
    customer_id = 56 # int | 
    customer_email_in = sromaster.CustomerEmailIn() # CustomerEmailIn | 

    try:
        # Add Customer Email
        api_response = await api_instance.add_customer_email_customers_customer_id_emails_post(customer_id, customer_email_in)
        print("The response of CustomersApi->add_customer_email_customers_customer_id_emails_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CustomersApi->add_customer_email_customers_customer_id_emails_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CustomersApi* | [**add_customer_email_customers_customer_id_emails_post**](docs/CustomersApi.md#add_customer_email_customers_customer_id_emails_post) | **POST** /customers/{customer_id}/emails | Add Customer Email
*CustomersApi* | [**add_customer_phone_customers_customer_id_phones_post**](docs/CustomersApi.md#add_customer_phone_customers_customer_id_phones_post) | **POST** /customers/{customer_id}/phones | Add Customer Phone
*CustomersApi* | [**create_customer_customers_post**](docs/CustomersApi.md#create_customer_customers_post) | **POST** /customers | Create Customer
*CustomersApi* | [**delete_customer_customers_customer_id_delete**](docs/CustomersApi.md#delete_customer_customers_customer_id_delete) | **DELETE** /customers/{customer_id} | Delete Customer
*CustomersApi* | [**delete_customer_email_customers_customer_id_emails_email_id_delete**](docs/CustomersApi.md#delete_customer_email_customers_customer_id_emails_email_id_delete) | **DELETE** /customers/{customer_id}/emails/{email_id} | Delete Customer Email
*CustomersApi* | [**delete_customer_phone_customers_customer_id_phones_phone_id_delete**](docs/CustomersApi.md#delete_customer_phone_customers_customer_id_phones_phone_id_delete) | **DELETE** /customers/{customer_id}/phones/{phone_id} | Delete Customer Phone
*CustomersApi* | [**get_customer_customers_customer_id_get**](docs/CustomersApi.md#get_customer_customers_customer_id_get) | **GET** /customers/{customer_id} | Get Customer
*CustomersApi* | [**list_customer_emails_customers_customer_id_emails_get**](docs/CustomersApi.md#list_customer_emails_customers_customer_id_emails_get) | **GET** /customers/{customer_id}/emails | List Customer Emails
*CustomersApi* | [**list_customer_phones_customers_customer_id_phones_get**](docs/CustomersApi.md#list_customer_phones_customers_customer_id_phones_get) | **GET** /customers/{customer_id}/phones | List Customer Phones
*CustomersApi* | [**list_customers_customers_get**](docs/CustomersApi.md#list_customers_customers_get) | **GET** /customers | List Customers
*CustomersApi* | [**update_customer_customers_customer_id_patch**](docs/CustomersApi.md#update_customer_customers_customer_id_patch) | **PATCH** /customers/{customer_id} | Update Customer
*CustomersApi* | [**update_customer_email_customers_customer_id_emails_email_id_patch**](docs/CustomersApi.md#update_customer_email_customers_customer_id_emails_email_id_patch) | **PATCH** /customers/{customer_id}/emails/{email_id} | Update Customer Email
*CustomersApi* | [**update_customer_phone_customers_customer_id_phones_phone_id_patch**](docs/CustomersApi.md#update_customer_phone_customers_customer_id_phones_phone_id_patch) | **PATCH** /customers/{customer_id}/phones/{phone_id} | Update Customer Phone
*ImInsurersApi* | [**create_im_insurer_im_insurers_post**](docs/ImInsurersApi.md#create_im_insurer_im_insurers_post) | **POST** /im-insurers | Create Im Insurer
*ImInsurersApi* | [**delete_im_insurer_im_insurers_insurer_id_delete**](docs/ImInsurersApi.md#delete_im_insurer_im_insurers_insurer_id_delete) | **DELETE** /im-insurers/{insurer_id} | Delete Im Insurer
*ImInsurersApi* | [**get_im_insurer_im_insurers_insurer_id_get**](docs/ImInsurersApi.md#get_im_insurer_im_insurers_insurer_id_get) | **GET** /im-insurers/{insurer_id} | Get Im Insurer
*ImInsurersApi* | [**list_im_insurers_im_insurers_get**](docs/ImInsurersApi.md#list_im_insurers_im_insurers_get) | **GET** /im-insurers | List Im Insurers
*ImInsurersApi* | [**update_im_insurer_im_insurers_insurer_id_patch**](docs/ImInsurersApi.md#update_im_insurer_im_insurers_insurer_id_patch) | **PATCH** /im-insurers/{insurer_id} | Update Im Insurer
*ImMailingApi* | [**create_item_im_mailing_post**](docs/ImMailingApi.md#create_item_im_mailing_post) | **POST** /im-mailing | Create Item
*ImMailingApi* | [**delete_item_im_mailing_item_id_delete**](docs/ImMailingApi.md#delete_item_im_mailing_item_id_delete) | **DELETE** /im-mailing/{item_id} | Delete Item
*ImMailingApi* | [**generate_items_im_mailing_generate_post**](docs/ImMailingApi.md#generate_items_im_mailing_generate_post) | **POST** /im-mailing/generate | Generate Items
*ImMailingApi* | [**get_item_im_mailing_item_id_get**](docs/ImMailingApi.md#get_item_im_mailing_item_id_get) | **GET** /im-mailing/{item_id} | Get Item
*ImMailingApi* | [**list_items_im_mailing_get**](docs/ImMailingApi.md#list_items_im_mailing_get) | **GET** /im-mailing | List Items
*ImMailingApi* | [**update_item_im_mailing_item_id_patch**](docs/ImMailingApi.md#update_item_im_mailing_item_id_patch) | **PATCH** /im-mailing/{item_id} | Update Item
*ImMailingInvoicesApi* | [**delete_invoice_im_mailing_item_id_invoices_invoice_id_delete**](docs/ImMailingInvoicesApi.md#delete_invoice_im_mailing_item_id_invoices_invoice_id_delete) | **DELETE** /im-mailing/{item_id}/invoices/{invoice_id} | Delete Invoice
*ImMailingInvoicesApi* | [**finalize_invoice_im_mailing_item_id_invoices_post**](docs/ImMailingInvoicesApi.md#finalize_invoice_im_mailing_item_id_invoices_post) | **POST** /im-mailing/{item_id}/invoices | Finalize Invoice
*ImMailingInvoicesApi* | [**get_invoice_download_url_im_mailing_item_id_invoices_invoice_id_download_url_get**](docs/ImMailingInvoicesApi.md#get_invoice_download_url_im_mailing_item_id_invoices_invoice_id_download_url_get) | **GET** /im-mailing/{item_id}/invoices/{invoice_id}/download-url | Get Invoice Download Url
*ImMailingInvoicesApi* | [**get_invoice_im_mailing_item_id_invoices_invoice_id_get**](docs/ImMailingInvoicesApi.md#get_invoice_im_mailing_item_id_invoices_invoice_id_get) | **GET** /im-mailing/{item_id}/invoices/{invoice_id} | Get Invoice
*ImMailingInvoicesApi* | [**list_invoices_im_mailing_item_id_invoices_get**](docs/ImMailingInvoicesApi.md#list_invoices_im_mailing_item_id_invoices_get) | **GET** /im-mailing/{item_id}/invoices | List Invoices
*ImMailingInvoicesApi* | [**request_upload_url_im_mailing_item_id_invoices_upload_url_post**](docs/ImMailingInvoicesApi.md#request_upload_url_im_mailing_item_id_invoices_upload_url_post) | **POST** /im-mailing/{item_id}/invoices/upload-url | Request Upload Url
*ImSrosApi* | [**create_im_sro_im_sros_post**](docs/ImSrosApi.md#create_im_sro_im_sros_post) | **POST** /im-sros | Create Im Sro
*ImSrosApi* | [**delete_im_sro_im_sros_sro_id_delete**](docs/ImSrosApi.md#delete_im_sro_im_sros_sro_id_delete) | **DELETE** /im-sros/{sro_id} | Delete Im Sro
*ImSrosApi* | [**get_im_sro_im_sros_sro_id_get**](docs/ImSrosApi.md#get_im_sro_im_sros_sro_id_get) | **GET** /im-sros/{sro_id} | Get Im Sro
*ImSrosApi* | [**list_im_sros_im_sros_get**](docs/ImSrosApi.md#list_im_sros_im_sros_get) | **GET** /im-sros | List Im Sros
*ImSrosApi* | [**update_im_sro_im_sros_sro_id_patch**](docs/ImSrosApi.md#update_im_sro_im_sros_sro_id_patch) | **PATCH** /im-sros/{sro_id} | Update Im Sro
*InsurancesApi* | [**get_insurance_insurances_insurance_id_get**](docs/InsurancesApi.md#get_insurance_insurances_insurance_id_get) | **GET** /insurances/{insurance_id} | Get Insurance
*InsurancesApi* | [**list_insurances_insurances_get**](docs/InsurancesApi.md#list_insurances_insurances_get) | **GET** /insurances | List Insurances
*OrganizationEmailsApi* | [**create_org_email_organization_emails_post**](docs/OrganizationEmailsApi.md#create_org_email_organization_emails_post) | **POST** /organization-emails | Create Org Email
*OrganizationEmailsApi* | [**delete_org_email_organization_emails_item_id_delete**](docs/OrganizationEmailsApi.md#delete_org_email_organization_emails_item_id_delete) | **DELETE** /organization-emails/{item_id} | Delete Org Email
*OrganizationEmailsApi* | [**get_org_email_organization_emails_item_id_get**](docs/OrganizationEmailsApi.md#get_org_email_organization_emails_item_id_get) | **GET** /organization-emails/{item_id} | Get Org Email
*OrganizationEmailsApi* | [**list_org_emails_organization_emails_get**](docs/OrganizationEmailsApi.md#list_org_emails_organization_emails_get) | **GET** /organization-emails | List Org Emails
*OrganizationEmailsApi* | [**update_org_email_organization_emails_item_id_patch**](docs/OrganizationEmailsApi.md#update_org_email_organization_emails_item_id_patch) | **PATCH** /organization-emails/{item_id} | Update Org Email
*OrganizationsApi* | [**create_organization_organizations_post**](docs/OrganizationsApi.md#create_organization_organizations_post) | **POST** /organizations | Create Organization
*OrganizationsApi* | [**delete_organization_organizations_organization_id_delete**](docs/OrganizationsApi.md#delete_organization_organizations_organization_id_delete) | **DELETE** /organizations/{organization_id} | Delete Organization
*OrganizationsApi* | [**get_organization_by_inn_organizations_by_inn_inn_get**](docs/OrganizationsApi.md#get_organization_by_inn_organizations_by_inn_inn_get) | **GET** /organizations/by-inn/{inn} | Get Organization By Inn
*OrganizationsApi* | [**get_organization_organizations_organization_id_get**](docs/OrganizationsApi.md#get_organization_organizations_organization_id_get) | **GET** /organizations/{organization_id} | Get Organization
*OrganizationsApi* | [**list_organization_emails_organizations_organization_id_emails_get**](docs/OrganizationsApi.md#list_organization_emails_organizations_organization_id_emails_get) | **GET** /organizations/{organization_id}/emails | List Organization Emails
*OrganizationsApi* | [**list_organization_insurances_organizations_organization_id_insurances_get**](docs/OrganizationsApi.md#list_organization_insurances_organizations_organization_id_insurances_get) | **GET** /organizations/{organization_id}/insurances | List Organization Insurances
*OrganizationsApi* | [**list_organizations_organizations_get**](docs/OrganizationsApi.md#list_organizations_organizations_get) | **GET** /organizations | List Organizations
*OrganizationsApi* | [**update_organization_organizations_organization_id_patch**](docs/OrganizationsApi.md#update_organization_organizations_organization_id_patch) | **PATCH** /organizations/{organization_id} | Update Organization
*ParserApi* | [**get_sro_by_inn_parser_sros_by_inn_inn_get**](docs/ParserApi.md#get_sro_by_inn_parser_sros_by_inn_inn_get) | **GET** /parser/sros/by-inn/{inn} | Get Sro By Inn
*ParserApi* | [**get_sro_member_by_inn_parser_sro_members_by_inn_inn_get**](docs/ParserApi.md#get_sro_member_by_inn_parser_sro_members_by_inn_inn_get) | **GET** /parser/sro-members/by-inn/{inn} | Get Sro Member By Inn
*ParserApi* | [**get_sro_member_parser_sro_members_member_id_get**](docs/ParserApi.md#get_sro_member_parser_sro_members_member_id_get) | **GET** /parser/sro-members/{member_id} | Get Sro Member
*ParserApi* | [**get_sro_parser_sros_sro_id_get**](docs/ParserApi.md#get_sro_parser_sros_sro_id_get) | **GET** /parser/sros/{sro_id} | Get Sro
*ParserApi* | [**list_sro_members_parser_sro_members_get**](docs/ParserApi.md#list_sro_members_parser_sro_members_get) | **GET** /parser/sro-members | List Sro Members
*ParserApi* | [**list_sros_parser_sros_get**](docs/ParserApi.md#list_sros_parser_sros_get) | **GET** /parser/sros | List Sros
*ParserWriteApi* | [**upsert_sro_members_parser_sro_members_post**](docs/ParserWriteApi.md#upsert_sro_members_parser_sro_members_post) | **POST** /parser/sro-members | Upsert Sro Members
*ParserWriteApi* | [**upsert_sro_parser_sros_post**](docs/ParserWriteApi.md#upsert_sro_parser_sros_post) | **POST** /parser/sros | Upsert Sro
*UsersApi* | [**get_me_users_me_get**](docs/UsersApi.md#get_me_users_me_get) | **GET** /users/me | Get Me


## Documentation For Models

 - [AccordanceStatus](docs/AccordanceStatus.md)
 - [CheckDisciplinaryAction](docs/CheckDisciplinaryAction.md)
 - [CheckOut](docs/CheckOut.md)
 - [CheckResult](docs/CheckResult.md)
 - [CheckType](docs/CheckType.md)
 - [CheckUpsertRequest](docs/CheckUpsertRequest.md)
 - [CustomerCreate](docs/CustomerCreate.md)
 - [CustomerEmailIn](docs/CustomerEmailIn.md)
 - [CustomerEmailOut](docs/CustomerEmailOut.md)
 - [CustomerOut](docs/CustomerOut.md)
 - [CustomerPhoneIn](docs/CustomerPhoneIn.md)
 - [CustomerPhoneOut](docs/CustomerPhoneOut.md)
 - [CustomerStatus](docs/CustomerStatus.md)
 - [CustomerUpdate](docs/CustomerUpdate.md)
 - [EmailSearchStatus](docs/EmailSearchStatus.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [IMInsurerCreate](docs/IMInsurerCreate.md)
 - [IMInsurerOut](docs/IMInsurerOut.md)
 - [IMInsurerUpdate](docs/IMInsurerUpdate.md)
 - [IMMailingCreate](docs/IMMailingCreate.md)
 - [IMMailingInvoiceOut](docs/IMMailingInvoiceOut.md)
 - [IMMailingInvoiceSummary](docs/IMMailingInvoiceSummary.md)
 - [IMMailingOutInput](docs/IMMailingOutInput.md)
 - [IMMailingOutOutput](docs/IMMailingOutOutput.md)
 - [IMMailingUpdate](docs/IMMailingUpdate.md)
 - [IMSroPublic](docs/IMSroPublic.md)
 - [IMSroUpsertRequest](docs/IMSroUpsertRequest.md)
 - [InsuranceOut](docs/InsuranceOut.md)
 - [InsurancePremium](docs/InsurancePremium.md)
 - [InsuranceUpsertRequest](docs/InsuranceUpsertRequest.md)
 - [InsuredSum](docs/InsuredSum.md)
 - [InvoiceFinalizeRequest](docs/InvoiceFinalizeRequest.md)
 - [InvoiceStatus](docs/InvoiceStatus.md)
 - [InvoiceUploadUrlRequest](docs/InvoiceUploadUrlRequest.md)
 - [InvoiceUploadUrlResponse](docs/InvoiceUploadUrlResponse.md)
 - [LegalForm](docs/LegalForm.md)
 - [MailingResult](docs/MailingResult.md)
 - [MailingStatus](docs/MailingStatus.md)
 - [MemberStatus](docs/MemberStatus.md)
 - [MessageStatus](docs/MessageStatus.md)
 - [OrganizationCreate](docs/OrganizationCreate.md)
 - [OrganizationEmailCreate](docs/OrganizationEmailCreate.md)
 - [OrganizationEmailOut](docs/OrganizationEmailOut.md)
 - [OrganizationEmailUpdate](docs/OrganizationEmailUpdate.md)
 - [OrganizationOut](docs/OrganizationOut.md)
 - [OrganizationPublic](docs/OrganizationPublic.md)
 - [OrganizationSchema](docs/OrganizationSchema.md)
 - [OrganizationUpdate](docs/OrganizationUpdate.md)
 - [PageCustomerOutInput](docs/PageCustomerOutInput.md)
 - [PageCustomerOutOutput](docs/PageCustomerOutOutput.md)
 - [PageIMInsurerOutInput](docs/PageIMInsurerOutInput.md)
 - [PageIMInsurerOutOutput](docs/PageIMInsurerOutOutput.md)
 - [PageIMMailingInvoiceOut](docs/PageIMMailingInvoiceOut.md)
 - [PageIMMailingOutInput](docs/PageIMMailingOutInput.md)
 - [PageIMMailingOutOutput](docs/PageIMMailingOutOutput.md)
 - [PageIMSroPublicInput](docs/PageIMSroPublicInput.md)
 - [PageIMSroPublicOutput](docs/PageIMSroPublicOutput.md)
 - [PageInsuranceOut](docs/PageInsuranceOut.md)
 - [PageOrganizationEmailOut](docs/PageOrganizationEmailOut.md)
 - [PageOrganizationOutInput](docs/PageOrganizationOutInput.md)
 - [PageOrganizationOutOutput](docs/PageOrganizationOutOutput.md)
 - [PageSROMemberListItemInput](docs/PageSROMemberListItemInput.md)
 - [PageSROMemberListItemOutput](docs/PageSROMemberListItemOutput.md)
 - [PageSROPublicInput](docs/PageSROPublicInput.md)
 - [PageSROPublicOutput](docs/PageSROPublicOutput.md)
 - [ParticipationStatus](docs/ParticipationStatus.md)
 - [ResponseDataCustomerEmailOut](docs/ResponseDataCustomerEmailOut.md)
 - [ResponseDataCustomerOut](docs/ResponseDataCustomerOut.md)
 - [ResponseDataCustomerPhoneOut](docs/ResponseDataCustomerPhoneOut.md)
 - [ResponseDataIMInsurerOut](docs/ResponseDataIMInsurerOut.md)
 - [ResponseDataIMMailingInvoiceOut](docs/ResponseDataIMMailingInvoiceOut.md)
 - [ResponseDataIMMailingOut](docs/ResponseDataIMMailingOut.md)
 - [ResponseDataIMSroPublic](docs/ResponseDataIMSroPublic.md)
 - [ResponseDataInsuranceOut](docs/ResponseDataInsuranceOut.md)
 - [ResponseDataInvoiceUploadUrlResponse](docs/ResponseDataInvoiceUploadUrlResponse.md)
 - [ResponseDataListCustomerEmailOut](docs/ResponseDataListCustomerEmailOut.md)
 - [ResponseDataListCustomerPhoneOut](docs/ResponseDataListCustomerPhoneOut.md)
 - [ResponseDataListIMMailingOut](docs/ResponseDataListIMMailingOut.md)
 - [ResponseDataListOrganizationEmailOut](docs/ResponseDataListOrganizationEmailOut.md)
 - [ResponseDataOrganizationEmailOut](docs/ResponseDataOrganizationEmailOut.md)
 - [ResponseDataOrganizationOut](docs/ResponseDataOrganizationOut.md)
 - [ResponseDataPageCustomerOut](docs/ResponseDataPageCustomerOut.md)
 - [ResponseDataPageIMInsurerOut](docs/ResponseDataPageIMInsurerOut.md)
 - [ResponseDataPageIMMailingInvoiceOut](docs/ResponseDataPageIMMailingInvoiceOut.md)
 - [ResponseDataPageIMMailingOut](docs/ResponseDataPageIMMailingOut.md)
 - [ResponseDataPageIMSroPublic](docs/ResponseDataPageIMSroPublic.md)
 - [ResponseDataPageInsuranceOut](docs/ResponseDataPageInsuranceOut.md)
 - [ResponseDataPageOrganizationEmailOut](docs/ResponseDataPageOrganizationEmailOut.md)
 - [ResponseDataPageOrganizationOut](docs/ResponseDataPageOrganizationOut.md)
 - [ResponseDataPageSROMemberListItem](docs/ResponseDataPageSROMemberListItem.md)
 - [ResponseDataPageSROPublic](docs/ResponseDataPageSROPublic.md)
 - [ResponseDataSROMemberDetails](docs/ResponseDataSROMemberDetails.md)
 - [ResponseDataSROPublic](docs/ResponseDataSROPublic.md)
 - [ResponseDataStr](docs/ResponseDataStr.md)
 - [ResponseDataUserResponse](docs/ResponseDataUserResponse.md)
 - [ResponsibilityLevel](docs/ResponsibilityLevel.md)
 - [RightStatus](docs/RightStatus.md)
 - [SROMemberDetailsInput](docs/SROMemberDetailsInput.md)
 - [SROMemberDetailsOutput](docs/SROMemberDetailsOutput.md)
 - [SROMemberListItemInput](docs/SROMemberListItemInput.md)
 - [SROMemberListItemOutput](docs/SROMemberListItemOutput.md)
 - [SROMemberUpsertRequest](docs/SROMemberUpsertRequest.md)
 - [SROPublic](docs/SROPublic.md)
 - [SROShort](docs/SROShort.md)
 - [SROStatus](docs/SROStatus.md)
 - [SROUpsertRequest](docs/SROUpsertRequest.md)
 - [SourceRegistry](docs/SourceRegistry.md)
 - [SrcModelsSroMemberRegistry](docs/SrcModelsSroMemberRegistry.md)
 - [TariffEntry](docs/TariffEntry.md)
 - [UserResponse](docs/UserResponse.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="HTTPBearer"></a>
### HTTPBearer

- **Type**: Bearer authentication


## Author

info@nexium.me


